module Fit

  # Copyright (c) 2002 Cunningham & Cunningham, Inc.
  # Released under the terms of the GNU General Public License version 2 or later.

  require "fit/Fixture"
  require "fit/Parse"
  
  class FileRunner

    # pass in the tags we're interested in. When run from
    # WikiRunner, this includes the additional <wiki> tag

    def initialize(tag_list = Fit::Parse::DEFAULT_TAGS)
      @tag_list = tag_list
    end

    # Run the test, returning the total number of errors
    def run(args)
      parse_arguments(args)
      fixture = Fixture.new()
      tables = Parse.new(@input_text, @tag_list)
      fixture.do_tables(tables)
      tables.print(@output)
      $stderr.puts(Fixture.counts)
      return Fixture.total_errors
      #  rescue Exception => e
      #   $stderr.puts e.message
      #   return -1
    end
    
    # We accept up to two arguments. The first argument is the name of
    # and input file (default stdin). The second is the name of an
    # output file (default stdout)
    
    def parse_arguments(args)
      
      usage if args.length > 2
      
      if args.length == 2
	begin
	  output_name = File.expand_path(args[1])
	  @output = File.open(output_name, "w")
	rescue
	  error("Output file #{args[1]} could not be opened: #{e.message}")
	end
      else
	@output = $stdout
	output_name = "standard output"
      end
      
      if args.length > 0
	begin
	  input_name = File.expand_path(args[0])
	  input = File.open(input_name)
	Fixture.summary["input update"] = input.mtime
	rescue Exception => e
	  error("Input file #{args[0]} could not be read: #{e.message}")
	end
      else
	input = $stdin
	input_name = "standard input"
	Fixture.summary["input update"] = Time.now
      end
      
      @input_text = input.read
      
      Fixture.summary["input file"]   = input_name
      Fixture.summary["output file"]  = output_name
    end
    
    
    def usage
      error("usage:  #{$0}  [ input_file  [ output_file ] ]")
    end
    
    def error(msg)
      $stderr.puts msg
      exit -1
    end
  end
end


######################################################################

if __FILE__ == $0
  
  runner = Fit::FileRunner.new
  
  error_count = runner.run(ARGV)
  
  exit(error_count)
  
end
